<?php
// This file is part of Moodle - http://moodle.org/
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Fetches data for js
 *
 * @package    atto_edusharing
 * @copyright  metaVentis GmbH — http://metaventis.com
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

global $CFG;

use mod_edusharing\EduSharingService;

require_once(__DIR__ . '/../../../../../config.php');

require_login();

$jsonstr = file_get_contents('php://input');
$jsonobj = json_decode($jsonstr, true);

$coursecontext = context_course::instance($jsonobj['courseid']);
if (!has_capability('moodle/course:update', $coursecontext)) {
    trigger_error(get_string('error_fetching_capability', 'editor_edusharing'), E_USER_WARNING);
    header('', true, 500);
    exit();
}

switch ($jsonobj['useCase']) {
    case 'getTicket':
        $edusharingservice = new EduSharingService();
        try {
            $ticket = $edusharingservice->get_ticket();
            echo $ticket;
        } catch (Exception $exception) {
            debugging($exception->getMessage());
        }
        break;
    default:
        echo "Error: No useCase";
}

exit();
